# --------------------------------------------------------------------
# Copyright © 2014 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
# --------------------------------------------------------------------


class Part:
    """Abstraction for system or click"""

    def __init__(self, name, tag, current_version, latest_version,
                 current_hash, active=True, installed=True):
        self.name = name
        self.tag = tag
        self.current_version = current_version
        self.latest_version = latest_version
        self.current_hash = current_hash

        # currently running (implies installed)
        self.active = active

        # installed, but not currently being used
        self.installed = installed


class DataSource:
    """A data source for snappy parts"""

    def versions(self, all_versions=False):
        """Return a list of @Part"""
        return []

    def do_update(self, names_to_update):
        """Update the specified parts"""
        return False

    def get_tags(self, part):
        """Return the available tags for a given part"""
        return []
